#--------------------------------------------------------------------------------
# FILE:       CreateADMTGroupList.ps1
#
# PROJECT:    Exchange 2010 /Hosting mode to Exchange 2010 SP2 Migration
#
# PURPOSE:    Sample script that parses the customer query output XML file
#             for Group information, then creates an output file
#             containing a list of group names formatted for use by ADMT
#
#
# THIS CODE AND INFORMATION IS PROVIDED TO YOU FOR YOUR REFERENTIAL PURPOSES 
# ONLY, AND IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EITHER 
# EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES 
# OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE, AND MAY NOT 
# BE REDISTRIBUTED IN ANY MANNER.
#
# Copyright (C) 2012 Microsoft Corporation. All rights reserved.
#--------------------------------------------------------------------------------

if ($args.length -ne 2)
{
	Write-Host "You must provide the name of the customer query results XML file and the" -foregroundcolor yellow
	Write-Host "NetBIOS domain name of the source domain as arguments." -foregroundcolor yellow
	Write-Host "Exiting script." -foregroundcolor yellow
	exit
}

$OrgXMLFile = $args[0]
$SourceDomainName = $args[1]

##### load the customer query results XML file
$error.clear()
$oldErrorCount = $error.Count
$xml = [xml](Get-Content $OrgXMLFile)

if ($error.Count -ne $oldErrorCount)
{
	[string]$problem = $error[0].Exception
	if ($problem.contains("because it does not exist"))
	{
		write-host "Unable to find C:\Scripts\$OrgXMLFile" -foregroundcolor yellow
		write-host "this file must be present in the C:\Scripts directory in order for the script to run." -foregroundcolor yellow
		write-host "Exiting script." -foregroundcolor yellow
		exit
	}
	Else
	{
		write-host $error[0].Exception -foregroundcolor red
		exit
	}
}

$CustomerName = $xml.response.data.customerOU
$OutputFile = $CustomerName + "Groups" + ".txt"

foreach ($group in $xml.response.data.groups.group)
{
	$GroupName = $SourceDomainName + "\" + $group.sAMAccountName
	Write-Host $GroupName 
	$GroupName | Out-File $OutputFile -append -encoding ASCII
}
Write-Host "==========================================================="
Write-Host ""
Write-Host "Created Group List file for ADMT named $OutputFile" -foregroundcolor green
