#--------------------------------------------------------------------------------
# FILE:       PrepareOrgMailboxes.ps1
#
# PROJECT:    Exchange 2010 /Hosting mode to Exchange 2010 SP2 Migration
#
# PURPOSE:    Sample script that parses the customer query output XML file
#             for mail-enabled Users, then passes this list to the
#             Prepare-MoveRequest script that ships with Exchange Server 2010 SP2
#
#
# THIS CODE AND INFORMATION IS PROVIDED TO YOU FOR YOUR REFERENTIAL PURPOSES 
# ONLY, AND IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EITHER 
# EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES 
# OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE, AND MAY NOT 
# BE REDISTRIBUTED IN ANY MANNER.
#
# Copyright (C) 2012 Microsoft Corporation. All rights reserved.
#--------------------------------------------------------------------------------

### Modify these variables with values appropriate to your environment ###

$LocalForestDC = "DC01.sp2enterprise.net"
$RemoteForestDC = "ad01.hostingmode.com"

$DomainID = "sp2enterprise"
$DomainSuffix = "net"
$HostingID = "Hosting"
$ResellerID = "Reseller001"

$BaseADPath = "OU=$ResellerID,OU=$HostingID,DC=$DomainID,DC=$DomainSuffix"

################### You should not need to edit any variables below this line ###################

if ($args.length -ne 2)
{
	Write-Host "You must provide the name of the customer XML output file and the customer OU name as an argument." -foregroundcolor yellow
	Write-Host "if there are spaces or special characters either, surround each with quotes." -foregroundcolor yellow
	Write-Host "Exiting script." -foregroundcolor yellow
	exit
}

$OrgXMLFile = $args[0]
$CustomerID = $args[1]

$arrMailboxesToPrepare = @()

$Timestamp = get-date -f yyyy-mm-dd-hhmmss
$ErrorLogfile = "PrepareOrgMailboxesLog-" + $OrgID + "-" + $Timestamp + ".txt"

## Start a transcript.  this will act as a log file.
Start-Transcript -path $ErrorLogfile
Write-Host "Beginning Bulk Preparation of customer organization mailboxes..." -foregroundcolor green

####################################################################
# Function to show a popup box
####################################################################
Function Show-Msgbox {
  Param([string]$message=$(Throw "You must specify a message"),
      [string]$button="okonly",
      [string]$icon="information",
      [string]$title="Message Box"
     )
     
# Buttons: OkOnly, OkCancel, AbortRetryIgnore, YesNoCancel, YesNo, RetryCancel
# Icons: Critical, Question, Exclamation, Information

  [reflection.assembly]::loadwithpartialname("microsoft.visualbasic") | Out-Null

  [microsoft.visualbasic.interaction]::Msgbox($message,"$button,$icon",$title) 

}
####################################################################

Show-Msgbox -message "In the next dialog box, enter LOCAL domain administrator credentials" -icon "information" -button "OkOnly" -title "Informational message"
$LocalCreds = Get-Credential

Show-Msgbox -message "In the next dialog box, enter REMOTE domain administrator credentials" -icon "information" -button "OkOnly" -title "Informational message"
$RemoteCreds = Get-Credential

#####################################

# pull in the data from input XML file
$OrgData = [xml](Get-Content $OrgXMLFile)

# parse the XML file and find all the User nodes
ForEach($User in $OrgData.GetElementsByTagName("user"))
{
	$Name = $User.name
	$UPN = $User.userPrincipalName
	$SourceDN = $User.distinguishedName
	$Alias = $User.mailNickname

	if ($Alias -gt "") # we only care about users that were mail-enabled in HMC
	{
		$MailEnabledUsersFound += 1
		Write-host "found mailbox $UPN - adding to list of mailboxes to be prepared" -foregroundcolor green
		$arrMailboxesToPrepare += $SourceDN
	}
}
# pass the list of mailboxes the Prepare-MoveRequestHosting script via the pipeline
Write-Host "Preparing mailboxes..." -foregroundcolor cyan

$arrMailboxesToPrepare | . .\Prepare-MoveRequest.ps1 -RemoteForestDomainController $RemoteForestDC -RemoteForestCredential $RemoteCreds -LocalForestDomainController $LocalForestDC -LocalForestCredential $LocalCreds -TargetMailUserOU "OU=$CustomerID,$BaseADPath" -DisableEmailAddressPolicy

Stop-transcript

Write-Host "Review the transcript file for any errors." -foregroundcolor cyan
Write-Host ""
